@@ -24,8 +24,10 @@ usethis::with_project(dummypackage, {
 
   suppressMessages(
     inflate(
-      pkg = dummypackage, flat_file = qmd_flat_file,
-      vignette_name = "Get started", check = FALSE,
+      pkg = dummypackage,
+      flat_file = qmd_flat_file,
+      vignette_name = "Get started",
+      check = FALSE,
       open_vignette = FALSE
     )
   )
